/**
 * Codes for errors generated within this library
 */
export declare const ZstdErrorCode: {
    readonly InvalidData: 0;
    readonly WindowSizeTooLarge: 1;
    readonly InvalidBlockType: 2;
    readonly FSEAccuracyTooHigh: 3;
    readonly DistanceTooFarBack: 4;
};
declare type ZEC = (typeof ZstdErrorCode)[keyof typeof ZstdErrorCode];
/**
 * An error generated within this library
 */
export interface ZstdError extends Error {
    /**
     * The code associated with this error
     */
    code: ZEC;
}
/**
 * Decompresses Zstandard data
 * @param dat The input data
 * @param buf The output buffer. If unspecified, the function will allocate
 *            exactly enough memory to fit the decompressed data. If your
 *            data has multiple frames and you know the output size, specifying
 *            it will yield better performance.
 * @returns The decompressed data
 */
export declare function decompress(dat: Uint8Array, buf?: Uint8Array): Uint8Array;
export {};
